package VMOMI::FibreChannelPortType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
